multidim.PointCloud.plot — GDA Toolbox v1.0 Manual

# multidim.PointCloud.plot

`PointCloud.` `plot`(canvas, cutoff=-1, color='purple', pos_edges=False, edge_alpha=-1.0, size=1, twocells=False, title='SimplicialComplex', label=False)

  Plot a PointCloud, decorated by various proeprties.

  Often slow!

  Parameters: | canvas : object An instance of `bokeh.plotting.figure.Figure` as in `canvas = bokeh.plotting.figure()` or an instance of `matplotlib.axes._subplots.AxesSubplot` as in `axes,canvas = matplotlib.pyplot.subplots()` cutoff : float if cutoff>=0, only draw edges up to length <cutoff twocells : boolean draw 2-cells (triangles)? title : string title for plot label : boolean label points in plot?

#### Previous topic

multidim.PointCloud.nearest_neighbors_slow

#### Next topic

multidim.PointCloud.reset